@@ -4,10 +4,14 @@ context("mcfs")
 #devtools::use_test("test.mcfs")
 
 test_that("MCFS artificial data", {
+  options(java.parameters = "-Xmx4g")
+  require(testthat)
+  require(rmcfs)
+  
   ####################################
   ######### Artificial data ##########
   ####################################
-  
+
   # create input data and review it
   adata <- artificial.data(rnd_features = 10, seed = 1)
   showme(adata)
